@@ -6,6 +6,8 @@ from ...utils import Utils
 
 
 class DataServiceClient(BaseClient):
+    """对账文件获取客户端"""
+
     def __init__(self, config):
         super().__init__(config)
 
@@ -23,6 +25,20 @@ class DataServiceClient(BaseClient):
             Utils.copy_dict(request.__dict__)
         )
 
+    def list_daily_order_v2(self, request: ListDailyOrderV2Request):
+        """ 查询日订单数据（支付和退款订单）
+
+        :type request: ListDailyOrderV2Request
+        :param request: the ListDailyOrderV2Request request parameters class.
+
+        :return: ListDailyOrderV2Response
+        """
+        return self._get(
+            "/api/dataservice/v2/orders",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
+
     def get_daily_order_file(self, request: GetDailyOrderFileRequest):
         """ 查询日订单文件
 
@@ -106,3 +122,31 @@ class DataServiceClient(BaseClient):
             request.request_id,
             Utils.copy_dict(request.__dict__)
         )
+
+    def list_daily_order_summary(self, request: ListDailyOrderSummaryRequest):
+        """ 查询日订单汇总数据
+
+        :type request: ListDailyOrderSummaryRequest
+        :param request: the ListDailyOrderSummaryRequest request parameters class.
+
+        :return: ListDailyOrderSummaryResponse
+        """
+        return self._get(
+            "/api/dataservice/v2/order/daily-summary",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
+
+    def list_monthly_order_summary(self, request: ListMonthlyOrderSummaryRequest):
+        """ 查询月订单汇总数据
+
+        :type request: ListMonthlyOrderSummaryRequest
+        :param request: the ListMonthlyOrderSummaryRequest request parameters class.
+
+        :return: ListMonthlyOrderSummaryResponse
+        """
+        return self._get(
+            "/api/dataservice/v2/order/monthly-summary",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
