@@ -6,6 +6,8 @@ from ...utils import Utils
 
 
 class InvoiceClient(BaseClient):
+    """发票开具客户端"""
+
     def __init__(self, config):
         super().__init__(config)
 
@@ -94,7 +96,7 @@ class InvoiceClient(BaseClient):
         )
 
     def send_reminder_email(self, request: SendReminderEmailRequest):
-        """ 发送发票扫描件压缩包下载链接邮件
+        """ 发送发票开具成功通知邮件
 
         :type request: SendReminderEmailRequest
         :param request: the SendReminderEmailRequest request parameters class.
